@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Pyserini: Python interface to the Anserini IR toolkit built on Lucene
 #
@@ -13,32 +12,31 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
+#
 
 import argparse
-import re
-from tqdm import tqdm
-from pyserini.search.pysearch import get_topics, SimpleSearcher
+from pyserini.search import get_topics, SimpleSearcher
 from pyserini.search.reranker import ClassifierType, PseudoRelevanceClassifierReranker
+from tqdm import tqdm
 
-parser = argparse.ArgumentParser(description='Create a input schema')
-parser.add_argument('-index', type=str, metavar='path to index',
-                    required=True, help='the path to lucene index')
-parser.add_argument('-topics', type=str, metavar='topic_name', required=True,
-                    help='topics name e.g. robust04, robust05, core17 & core18')
-parser.add_argument('-output', type=str, metavar='path',
-                    help='path to the output file')
-parser.add_argument('-bm25',  action='store_true', default=True,
-                    help='use bm25 ranker by default')
-parser.add_argument('-rm3',  action='store_true', help='use rm3 ranker')
-parser.add_argument('-qld',  action='store_true', help='use qld ranker')
-parser.add_argument('-prcl',  type=ClassifierType, nargs='+', default=[],
-                    help='specify the classifier PseudoRelevanceClassifierReranker uses')
-parser.add_argument('-prcl.r',  dest='r', type=int, default=10,
-                    help='number of positive labels in pseudo relevance feedback')
-parser.add_argument('-prcl.n', dest='n', type=int, default=100,
-                    help='number of negative labels in pseudo relevance feedback')
-parser.add_argument('-prcl.alpha', dest='alpha', type=float, default=0.5,
-                    help='alpha value for interpolation in pseudo relevance feedback')
+parser = argparse.ArgumentParser(description='Search a Lucene index.')
+parser.add_argument('--index', type=str, metavar='path to index', required=True, help="Path to Lucene index.")
+parser.add_argument('--topics', type=str, metavar='topic_name', required=True,
+                    help="Name of topics. Available: robust04, robust05, core17, core18.")
+parser.add_argument('--output', type=str, metavar='path', help="Path to output file.")
+parser.add_argument('--bm25',  action='store_true', default=True, help="Use BM25 (default).")
+parser.add_argument('--rm3',  action='store_true', help="Use RM3")
+parser.add_argument('--qld',  action='store_true', help="Use QLD")
+parser.add_argument('--prcl',  type=ClassifierType, nargs='+', default=[],
+                    help='Specify the classifier PseudoRelevanceClassifierReranker uses.')
+parser.add_argument('--prcl.vectorizer',  dest='vectorizer', type=str,
+                    help='Type of vectorizer. Available: TfidfVectorizer, BM25Vectorizer.')
+parser.add_argument('--prcl.r',  dest='r', type=int, default=10,
+                    help='Number of positive labels in pseudo relevance feedback.')
+parser.add_argument('--prcl.n', dest='n', type=int, default=100,
+                    help='Number of negative labels in pseudo relevance feedback.')
+parser.add_argument('--prcl.alpha', dest='alpha', type=float, default=0.5,
+                    help='Alpha value for interpolation in pseudo relevance feedback.')
 args = parser.parse_args()
 
 topics = get_topics(args.topics)
@@ -63,7 +61,8 @@ if topics == {}:
 # get re-ranker
 use_prcl = args.prcl and len(args.prcl) > 0 and args.alpha > 0
 if use_prcl is True:
-    ranker = PseudoRelevanceClassifierReranker(args.index, args.prcl, r=args.r, n=args.n, alpha=args.alpha)
+    ranker = PseudoRelevanceClassifierReranker(
+        args.index, args.vectorizer, args.prcl, r=args.r, n=args.n, alpha=args.alpha)
 
 # build output path
 output_path = args.output
@@ -77,17 +76,17 @@ if output_path is None:
                 clf_rankers.append('svm')
 
         r_str = f'prcl.r_{args.r}'
-        n_str = f'prcl.r_{args.n}'
+        n_str = f'prcl.n_{args.n}'
         a_str = f'prcl.alpha_{args.alpha}'
         clf_str = 'prcl_' + '+'.join(clf_rankers)
         tokens1 = ['run', args.topics, '+'.join(search_rankers)]
-        tokens2 = [clf_str, r_str, n_str, a_str]
+        tokens2 = [args.vectorizer, clf_str, r_str, n_str, a_str]
         output_path = '.'.join(tokens1) + '-' + '-'.join(tokens2) + ".txt"
     else:
         tokens = ['run', args.topics, '+'.join(search_rankers), 'txt']
         output_path = '.'.join(tokens)
 
-print('Output ->', output_path)
+print(f'Running {args.topics} topics, saving to {output_path}...')
 
 with open(output_path, 'w') as target_file:
     for index, topic in enumerate(tqdm(sorted(topics.keys()))):
